Skip to contents

Balance metric (in the case of a binary tree), which measures the sum across all internal nodes of one over the maximum depth of all attached tips to that node. When calculated on a binary tree, the b1 statistic is a true balance statistic (meaning that the caterpillar tree is the most extreme, unbalanced tree). However, the treestats package also supports calculation on non-binary trees.

Usage

b1(phy, normalization = "none")

Arguments

phy

phylo object or ltable

normalization

"none" or "tips", in which case the resulting statistic is divided by the number of tips in the tree, as a crude way of normalization.

Value

B1 statistic

References

K.-T. Shao and R. R. Sokal. Tree Balance. Systematic Zoology, 39(3):266, 1990. doi: 10.2307/2992186.