Calculates the eigenvalues of the Laplacian Matrix, where the Laplacian matrix is the matrix representation of a graph, in this case a phylogeny. When the R package RSpectra is available, a faster calculation can be used, which does not calculate all eigenvalues, but only the maximum and minimum. As such, when using this option, the vector of all eigenvalues is not returned.
Arguments
- phy
phylo object or ltable
- use_rspectra
boolean to indicate whether the helping package RSpectra should be used, in which case only the minimum and maximum values are returned, and not the full list of eigenvalues, which makes the computation much faster.
- force_min
boolean to indicate whether or not to also calculate the minimum positive eigenvalue if the tree is larger than 23170 tips. Default is FALSE, as this can be very slow, but in some cases might be of interest.