Balance metric (in the case of a binary tree), which measures the sum across all internal nodes of one over the maximum depth of all attached tips to that node. When calculated on a binary tree, the b1 statistic is a true balance statistic (meaning that the caterpillar tree is the most extreme, unbalanced tree). However, the treestats package also supports calculation on non-binary trees.